#[repr(u8)]pub enum SerialInterfaceType {
SpiRisingEdge = 0,
SpiFallingEdge = 1,
ManchesterRising0 = 2,
ManchesterRising1 = 3,
}Expand description
Serial interface type and sampling edge.
Variants
SpiRisingEdge = 0
SPI mode sampling on the rising edge of the clock
SpiFallingEdge = 1
SPI mode sampling on the falling edge of the clock
ManchesterRising0 = 2
Manchester coded: rising edge = logic 0, falling edge = logic 1
ManchesterRising1 = 3
Manchester coded: rising edge = logic 1, falling edge = logic 0